"""Demonstrate a synth function that uses a subclass of HeliStack."""

from cdktf import LocalExecProvisioner, TerraformLocal, TerraformOutput, TerraformVariable
from cdktf_cdktf_provider_null.resource import Resource as NullResource

from helicopyter import HeliStack


class NewStack(HeliStack):
    """Infer the ENVIronment (ENVI) from the workspace. Provide it and COdeNAme (CONA) as locals."""

    def __init__(self, cona: str) -> None:
        super().__init__(cona)
        self.push(TerraformLocal, 'cona', self.cona)
        self.push(TerraformLocal, 'envi', '${terraform.workspace}')
        self.push(
            NullResource,
            'this',
            provisioners=[
                LocalExecProvisioner(
                    command='echo $envi', environment={'envi': '${local.envi}'}, type='local-exec'
                )
            ],
        )
        gash = self.push(TerraformVariable, 'gash', type='string')
        self.push(TerraformOutput, 'gash', value=gash.to_string())


def synth(stack: NewStack) -> None:  # noqa: ARG001
    pass



"""Upstream CDKTF example to compare with Helicopyter."""

from cdktf import App, TerraformStack
from cdktf_cdktf_provider_docker.container import Container
from cdktf_cdktf_provider_docker.image import Image
from cdktf_cdktf_provider_docker.provider import DockerProvider
from constructs import Construct


class MyStack(TerraformStack):
    def __init__(self, scope: Construct, ns: str) -> None:
        super().__init__(scope, ns)

        DockerProvider(self, 'docker')

        docker_image = Image(self, 'nginxImage', name='nginx:latest', keep_locally=False)

        Container(
            self,
            'nginxContainer',
            name='tutorial',
            image=docker_image.name,
            ports=[{'internal': 80, 'external': 8000}],
        )


app = App()
MyStack(app, 'learn-cdktf-docker')

app.synth()



"""Helicopyter example to compare with upstream CDKTF."""

from cdktf_cdktf_provider_docker.container import Container
from cdktf_cdktf_provider_docker.image import Image

from helicopyter import HeliStack


def synth(stack: HeliStack) -> None:
    stack.provide('docker')

    docker_image = stack.push(Image, 'nginxImage', name='nginx:latest', keep_locally=False)

    stack.push(
        Container,
        'nginxContainer',
        name='tutorial',
        image=docker_image.name,
        ports=[{'internal': 80, 'external': 8000}],
    )
